#ifndef Board_h
#define Board_h

#define ICswift_SAM7

#define __inline static inline

#include <inttypes.h>
#include "AT91SAM7X256.h"
#include "lib_AT91SAM7X256.h"


#define __ramfunc __attribute__ ((long_call, section (".fastrun")))

#define true	-1
#define false	0


#define  INT_SRAM           0x00200000
#define  INT_SRAM_REMAP	    0x00000000

#define  INT_FLASH          0x00000000
#define  INT_FLASH_REMAP    0x00100000

#define  FLASH_PAGE_NB		AT91C_IFLASH_NB_OF_PAGES
#define  FLASH_PAGE_SIZE	AT91C_IFLASH_PAGE_SIZE

#if defined(ICswift_SAM7)

/*-----------------*/
/* LEDs Definition */
/*-----------------*/
#define LED1            (1<<8)	
#define LED2            (1<<9)
#define LED_MASK        (LED1|LED2)

#define LED1_OFF() AT91F_PIO_SetOutput( AT91C_BASE_PIOA, LED1);    
#define LED1_ON()  AT91F_PIO_ClearOutput( AT91C_BASE_PIOA, LED1);  
#define LED1_TOGGLE() if ((AT91F_PIO_GetInput(AT91C_BASE_PIOA) & LED1 ) == LED1 ) {	LED1_ON();}	else {LED1_OFF();}

#define LED2_OFF() AT91F_PIO_SetOutput( AT91C_BASE_PIOA, LED2);    
#define LED2_ON()  AT91F_PIO_ClearOutput( AT91C_BASE_PIOA, LED2);  
#define LED2_TOGGLE() if ((AT91F_PIO_GetInput(AT91C_BASE_PIOA) & LED2 ) == LED2 ) {	LED2_ON();}	else {LED2_OFF();}

/*------------------*/
/* USART Definition */
/*------------------*/
/* SUB-D 9 points J3 DBGU */

#define DBGU_RXD		AT91C_PA9_DRXD	  
#define DBGU_TXD		AT91C_PA10_DTXD	  
#define AT91C_DBGU_BAUD	   115200   // Baud rate

#define US_RXD_PIN		AT91C_PA0_RXD0    
#define US_TXD_PIN		AT91C_PA1_TXD0    


/*------------------*/
/* Radio Definition */
/*------------------*/
#define RF_MOSI		AT91C_PA23_MOSI1
#define RF_MISO		AT91C_PA24_MISO1 
#define RF_SCK		AT91C_PA22_SPCK1

#define RF_RESET	AT91C_PIO_PA26
#define RF_SLP_TR	AT91C_PIO_PA25 
#define RF_IRQ		AT91C_PIO_PA30
#define RF_SELN		AT91C_PIO_PA29
#define RF_CLKM		AT91C_PIO_PA15 

#else
#error "Unsupported board"
#endif

/*=== TRX pin access macros ==========================================*/


#define TRX_RESET_HIGH() AT91F_PIO_SetOutput( AT91C_BASE_PIOA, RF_RESET );    /**< set RESET pin to high level */
#define TRX_RESET_LOW()  AT91F_PIO_ClearOutput( AT91C_BASE_PIOA, RF_RESET );  /**< set RESET pin to low level */

/** set SLEEP_TR pin to high level */
#define TRX_SLPTR_HIGH() AT91F_PIO_SetOutput( AT91C_BASE_PIOA, RF_SLP_TR );    
/**< set SLEEP_TR pin to low level */
#define TRX_SLPTR_LOW()  AT91F_PIO_ClearOutput( AT91C_BASE_PIOA, RF_SLP_TR );  

/** set SS line to high level */
#define SPI_SELN_HIGH()  AT91F_PIO_SetOutput( AT91C_BASE_PIOA, RF_SELN );
/** set SS line to low level */
#define SPI_SELN_LOW()   AT91F_PIO_ClearOutput( AT91C_BASE_PIOA, RF_SELN ); 

/*------------------*/
/* CAN Definition */
/*------------------*/

#define CAN_RS		AT91C_PIO_PB27
#define CAN_EN		AT91C_PIO_PB28
#define CAN_RX		AT91C_PIO_PA19
#define CAN_TX		AT91C_PIO_PA20

#define CAN_RS_HIGH() AT91F_PIO_SetOutput( AT91C_BASE_PIOA, CAN_RS );    /**< set CAN_RS pin to high level */
#define CAN_RS_LOW()  AT91F_PIO_ClearOutput( AT91C_BASE_PIOA, CAN_RS );  /**< set CAN_RS pin to low level */

#define CAN_EN_HIGH() AT91F_PIO_SetOutput( AT91C_BASE_PIOA, CAN_EN );    /**< set CAN_EN pin to high level */
#define CAN_EN_LOW()  AT91F_PIO_ClearOutput( AT91C_BASE_PIOA, CAN_EN );  /**< set CAN_EN pin to low level */

/*--------------*/
/* Master Clock */
/*--------------*/

#define EXT_OC          18432000   // External crystal
#define MCK             48054857   // MCK (PLLRC div by 2)
#define MCKKHz          (MCK/1000) //

#endif /* Board_h */
