/******************************************************************************/
/*  This file has been a part of the uVision/ARM development tools            */
/*  Copyright KEIL ELEKTRONIK GmbH 2002-2004                                  */
/******************************************************************************/
/*                                                                            */
/*  SERIAL.C:  Low Level Serial Routines                                      */
/*                                                                            */
/******************************************************************************/

/* 
   Martin Thomas : 
   - slightly modified for the WinARM example 
   - changed function names to avoid comflict with "stdio"
     (so far no syscalls for the newlib...)
   - Keil seems to "reject" the AT91lib*.h. Don't know
     why since the layer is "thin". Maybe will change this to 
	 "lib Style" in later version...
*/

#include "Board.h"

#define BR    115200                        /* Baud Rate */

#define BRD  (MCK/16/BR)                    /* Baud Rate Divisor */
AT91S_USART *pUSART1 = AT91C_BASE_US1;      /* Global Pointer to USART1 */

void uart1_init (void) {                   /* Initialize Serial Interface */

  /* mt: n.b: uart0 clock must be enabled to use it */
  
  pUSART1->US_CR = AT91C_US_RSTRX |          /* Reset Receiver      */
                  AT91C_US_RSTTX |          /* Reset Transmitter   */
                  AT91C_US_RXDIS |          /* Receiver Disable    */
                  AT91C_US_TXDIS;           /* Transmitter Disable */

  pUSART1->US_MR = AT91C_US_USMODE_NORMAL |  /* Normal Mode */
                  AT91C_US_CLKS_CLOCK    |  /* Clock = MCK */
                  AT91C_US_CHRL_8_BITS   |  /* 8-bit Data  */
                  AT91C_US_PAR_NONE      |  /* No Parity   */
                  AT91C_US_NBSTOP_1_BIT;    /* 1 Stop Bit  */

  pUSART1->US_BRGR = BRD;                    /* Baud Rate Divisor */

  pUSART1->US_CR = AT91C_US_RXEN  |          /* Receiver Enable     */
                  AT91C_US_TXEN;            /* Transmitter Enable  */
}

void uart1_PutHex(	uint8_t value)
{
	uint8_t dummy;
    while (!AT91F_US_TxReady((AT91PS_USART)AT91C_BASE_US1));
	dummy= value >> 4;
	if(dummy<10)
	{
		AT91F_US_PutChar((AT91PS_USART)AT91C_BASE_US1, dummy + 48);
	}
	else
	{
		dummy-=10;
		AT91F_US_PutChar((AT91PS_USART)AT91C_BASE_US1, dummy + 65);
	}
	
    while (!AT91F_US_TxReady((AT91PS_USART)AT91C_BASE_US1));
	dummy= value & 0x0F;
	if(dummy<10)
	{
		AT91F_US_PutChar((AT91PS_USART)AT91C_BASE_US1, dummy + 48);
	}
	else
	{
		dummy-=10;
		AT91F_US_PutChar((AT91PS_USART)AT91C_BASE_US1, dummy + 65);
	}
}


int uart1_putc(int ch) 
{	
	while (!(pUSART1->US_CSR & AT91C_US_TXRDY));   /* Wait for Empty Tx Buffer */
	return (pUSART1->US_THR = ch);                 /* Transmit Character */
}	

int uart1_putchar (int ch) {                      /* Write Character to Serial Port */

  if (ch == '\n')  {                            /* Check for LF */
    uart1_putc( '\r' );                         /* Output CR */
  }
  return uart1_putc( ch );                     /* Transmit Character */
}

int uart1_puts ( char* s )
{
	while ( *s ) uart1_putchar( *s++ );
	return 0;
}

int uart1_kbhit( void ) /* returns true if character in receive buffer */
{	
	if ( pUSART1->US_CSR & AT91C_US_RXRDY) {
		return 1;
	}
	else {
		return 0;
	}
}

int uart1_getc ( void )  /* Read Character from Serial Port */
{    

  while (!(pUSART1->US_CSR & AT91C_US_RXRDY));   /* Wait for Full Rx Buffer */
  return (pUSART1->US_RHR);                      /* Read Character */
}



